#ifndef NOTEMANAGER_H
#define NOTEMANAGER_H

#include <string>
#include <math.h>
#include <iostream>

/**
 * @brief Permite el manejo de notas musicales
 */
class NoteManager
{
public:
    NoteManager();
    /**
     * @brief Permite obtener la nota mas cercana a partir de una frecuencia dada
     * @param freq frecuencia de la nota en ejecución
     * @return string que contiene la nota en clave americana
     */
    std::string getNearNote(double freq);
    /**
     * @brief Permite obtener la cantidad (en cents) de desafinación respecto a la nota mas cercana
     * @param freq frecuencia de la nota en ejecución
     * @return cantidad de cents de desviación de la nota
     */
    int getCentPitch(double freq);

private:

    /**
     * @brief Genera tabla con frecuencias discretas de un piano tradicional (octava -1 a 8)
     */
    void generateFreqTable();
    /**
     * @brief Permite obtener la frecuencia mas cercana a la tabla a partir de una frecuencia dada
     * @param freq frecuencia de la nota en ejecución
     * @return frecuencia mas cercana de la tabla
     */
    short getNearFreqPosition(double freq);

    std::string american_notes[12] = {"A", "Bb", "B", "C", "C#", "D", "Eb", "E", "F", "F#", "G", "Ab"};
    double *freq_table;

};

#endif // NOTEMANAGER_H
